==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/withdrawals.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   withdrawals.lang.inc.php 2020-01-09
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2020 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'create_modal_close'                                 => 'Schließen',
    'create_modal_confirm'                               => 'Weiter',
    'create_modal_labels_order_id'                       => 'Bestellnummer',
    'create_modal_text'                                  => 'Geben Sie die Bestellnummer an, für die Sie einen Widerruf erstellen wollen.',
    'create_modal_title'                                 => 'Widerruf erstellen',
    'delete_modal_close'                                 => 'Schließen',
    'delete_modal_confirm'                               => 'Löschen',
    'delete_modal_label_customer'                        => 'Kunde',
    'delete_modal_label_date'                            => 'Datum',
    'delete_modal_label_id'                              => 'Widerrufs ID',
    'delete_modal_label_order'                           => 'Bestellung',
    'delete_modal_text'                                  => 'Sind Sie sicher, dass Sie folgenden Widerruf löschen wollen?',
    'delete_modal_title'                                 => 'Widerruf löschen?',
    'details_modal_close'                                => 'Schließen',
    'details_modal_label_address'                        => 'Adresse',
    'details_modal_label_customer_details'               => 'Kundendetails',
    'details_modal_label_email'                          => 'E-Mail',
    'details_modal_label_female_customer'                => 'Frau',
    'details_modal_label_male_customer'                  => 'Herr',
    'details_modal_label_order_date'                     => 'Bestellt am',
    'details_modal_label_order_delivery_date'            => 'Erhalten am',
    'details_modal_label_order_details'                  => 'Bestelldetails',
    'details_modal_label_withdrawal'                     => 'Widerruf',
    'details_modal_label_withdrawal_created_by_admin'    => 'durch Admin',
    'details_modal_label_withdrawal_created_by_customer' => 'durch Kunde',
    'details_modal_label_withdrawal_created_on'          => 'Erstellt am',
    'details_modal_label_withdrawal_date'                => 'Widerrufsdatum',
    'details_modal_label_withdrawal_order_id'            => 'Bestellnummer',
    'details_modal_title'                                => 'Widerruf bearbeiten',
    'details_modal_update_order_id'                      => 'Neue Bestellnummer speichern',
    'error_could_not_delete_withdrawal'                  => 'Der Widerruf konnte nicht gelöscht werden.',
    'error_could_not_load_withdrawal_details'            => 'Die Widerrufsdetails konnten nicht geladen werden.',
    'error_could_not_load_withdrawals'                   => 'Die Widerrufe konnten nicht geladen werden.',
    'error_could_not_update_order_id'                    => 'Die Bestellnummer des Widerrufs konnte nicht aktualisiert werden.',
    'label_column_customer'                              => 'Kunde',
    'label_column_date'                                  => 'Datum',
    'label_column_date_by_admin'                         => 'durch Admin',
    'label_column_date_by_customer'                      => 'durch Kunde',
    'label_column_id'                                    => 'ID',
    'label_column_order'                                 => 'Bestellung',
    'label_offset_of'                                    => 'von',
    'label_offset_to'                                    => 'bis',
    'label_page_next'                                    => 'Nächste',
    'label_page_previous'                                => 'Vorherige',
    'no_withdrawals_exist'                               => 'Es existieren keine Widerrufe.',
    'option_limits_10'                                   => '10 pro Seite',
    'option_limits_100'                                  => '100 pro Seite',
    'option_limits_25'                                   => '25 pro Seite',
    'option_limits_50'                                   => '50 pro Seite',
    'title'                                              => 'Widerrufe',
    'updated_order_id_successful'                        => 'Bestellnummer wurde erfolgreich aktualisiert.',
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/withdrawals.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   withdrawals.lang.inc.php 2021-05-15
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2021 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'create_modal_close'                                 => 'Schließen',
    'create_modal_confirm'                               => 'Weiter',
    'create_modal_labels_order_id'                       => 'Bestellnummer',
    'create_modal_text'                                  => 'Gib die Bestellnummer an, für die du einen Widerruf erstellen willst.',
    'create_modal_title'                                 => 'Widerruf erstellen',
    'delete_modal_close'                                 => 'Schließen',
    'delete_modal_confirm'                               => 'Löschen',
    'delete_modal_label_customer'                        => 'Kunde',
    'delete_modal_label_date'                            => 'Datum',
    'delete_modal_label_id'                              => 'Widerrufs ID',
    'delete_modal_label_order'                           => 'Bestellung',
    'delete_modal_text'                                  => 'Bist du sicher, dass du folgenden Widerruf löschen willst?',
    'delete_modal_title'                                 => 'Widerruf löschen?',
    'details_modal_close'                                => 'Schließen',
    'details_modal_label_address'                        => 'Adresse',
    'details_modal_label_customer_details'               => 'Kundendetails',
    'details_modal_label_email'                          => 'E-Mail',
    'details_modal_label_female_customer'                => 'Frau',
    'details_modal_label_male_customer'                  => 'Herr',
    'details_modal_label_order_date'                     => 'Bestellt am',
    'details_modal_label_order_delivery_date'            => 'Erhalten am',
    'details_modal_label_order_details'                  => 'Bestelldetails',
    'details_modal_label_withdrawal'                     => 'Widerruf',
    'details_modal_label_withdrawal_created_by_admin'    => 'durch Admin',
    'details_modal_label_withdrawal_created_by_customer' => 'durch Kunde',
    'details_modal_label_withdrawal_created_on'          => 'Erstellt am',
    'details_modal_label_withdrawal_date'                => 'Widerrufsdatum',
    'details_modal_label_withdrawal_order_id'            => 'Bestellnummer',
    'details_modal_title'                                => 'Widerruf bearbeiten',
    'details_modal_update_order_id'                      => 'Neue Bestellnummer speichern',
    'error_could_not_delete_withdrawal'                  => 'Der Widerruf konnte nicht gelöscht werden.',
    'error_could_not_load_withdrawal_details'            => 'Die Widerrufsdetails konnten nicht geladen werden.',
    'error_could_not_load_withdrawals'                   => 'Die Widerrufe konnten nicht geladen werden.',
    'error_could_not_update_order_id'                    => 'Die Bestellnummer des Widerrufs konnte nicht aktualisiert werden.',
    'label_column_customer'                              => 'Kunde',
    'label_column_date'                                  => 'Datum',
    'label_column_date_by_admin'                         => 'durch Admin',
    'label_column_date_by_customer'                      => 'durch Kunde',
    'label_column_id'                                    => 'ID',
    'label_column_order'                                 => 'Bestellung',
    'label_offset_of'                                    => 'von',
    'label_offset_to'                                    => 'bis',
    'label_page_next'                                    => 'Nächste',
    'label_page_previous'                                => 'Vorherige',
    'no_withdrawals_exist'                               => 'Es existieren keine Widerrufe.',
    'option_limits_10'                                   => '10 pro Seite',
    'option_limits_100'                                  => '100 pro Seite',
    'option_limits_25'                                   => '25 pro Seite',
    'option_limits_50'                                   => '50 pro Seite',
    'title'                                              => 'Widerrufe',
    'updated_order_id_successful'                        => 'Bestellnummer wurde erfolgreich aktualisiert.',
];
